==> haskell-either-5.0.1.1-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 5.0.1.1
id: either-5.0.1.1-Gmt1eHcFDTICtD7GOyagFT
key: either-5.0.1.1-Gmt1eHcFDTICtD7GOyagFT
license: BSD-3-Clause
copyright: Copyright (C) 2008-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: Combinators for working with sums
description:
    Combinators for working with sums.
category: Control, Monads
abi: 4cdcd7ebd0064a20bae5bdf81eb68b39
exposed: True
exposed-modules:
    Data.Either.Combinators Data.Either.Validation
import-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/either-5.0.1.1
hs-libraries: HSeither-5.0.1.1-Gmt1eHcFDTICtD7GOyagFT
depends:
    base-4.12.0.0 bifunctors-5.5.4-GgGMyhSusMG6kFYtRQpoS7 mtl-2.2.2
    profunctors-5.4-8SgccOoggxTAmI1JMELV50
    semigroupoids-5.3.2-4AsvIVMQIH9DuCVwKKp02j
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.1.1-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: either
version: 5.0.1.1
id: either-5.0.1.1-7hr5RhXy4Gs2hmqdZxPR9U
key: either-5.0.1.1-7hr5RhXy4Gs2hmqdZxPR9U
license: BSD-3-Clause
copyright: Copyright (C) 2008-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/either/
synopsis: Combinators for working with sums
description:
    Combinators for working with sums.
category: Control, Monads
abi: 418418de7855bd9e13dac4151097687d
exposed: True
exposed-modules:
    Data.Either.Combinators Data.Either.Validation
import-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/either-5.0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/either-5.0.1.1
hs-libraries: HSeither-5.0.1.1-7hr5RhXy4Gs2hmqdZxPR9U
depends:
    base-4.12.0.0 bifunctors-5.5.4-9Tb0bkUz5VW2Ucg8P8K6vJ mtl-2.2.2
    profunctors-5.4-Dq7lbhRyDqlE72xPOLahfX
    semigroupoids-5.3.2-K5SaVm4N6AL6wYPHZFU5px
haddock-interfaces: /usr/share/doc/haskell-either/html/either.haddock
haddock-html: /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
